@@ -1,10 +1,12 @@
 """
     Middleware to help manage the Slumber client.
 """
-from django.contrib.auth import authenticate
-
 from slumber import client
-from slumber._caches import CLIENT_INSTANCE_CACHE
+from slumber._caches import CLIENT_INSTANCE_CACHE, PER_THREAD
+
+
+# Django defines the class members as methods
+# pylint: disable=R0201
 
 
 class Cache(object):
@@ -12,8 +14,6 @@ class Cache(object):
     of each request.
     """
 
-    # Django defines this as a method
-    # pylint: disable=R0201
     def process_request(self, _request):
         """Turn the cache on.
         """
@@ -27,19 +27,22 @@ class Cache(object):
         return response
 
 
-class Authentication(object):
-    """Used when authentication is delegated from a remote host.
+class ForwardAuthentication(object):
+    """Used to forward authentication of the currently logged in user to
+    another backend.
     """
 
-    # Django defines this as a method
-    # pylint: disable=R0201
     def process_request(self, request):
-        """Looks for the X_FOST_User header, and if found authenticates that
-        user.
+        """Save the request in thread local storage so it can be retrieved
+        by the user agent when it makes requests.
         """
-        user_header = request.META.get('HTTP_X_FOST_USER', None)
-        if user_header:
-            user = authenticate(x_fost_user=user_header)
-            if user:
-                request.user = user
+        PER_THREAD.request = request
 
+    def process_response(self, request, response):
+        """Forget the request, but do an assert to make sure nothing horrible
+        has happened to it first.
+        """
+        assert PER_THREAD.request is request
+        PER_THREAD.request = None
+        PER_THREAD.username = None
+        return response
