@@ -6,12 +6,12 @@ from slumber.server import get_slumber_root
 
 
 DATA_MAPPING = {
-        'django.db.models.fields.AutoField': lambda m, i, fm, v: v,
-        'django.db.models.fields.BooleanField': lambda m, i, fm, v: v,
+        'django.db.models.fields.AutoField': lambda r, m, i, fm, v: v,
+        'django.db.models.fields.BooleanField': lambda r, m, i, fm, v: v,
     }
 
 
-def to_json_data(model, instance, fieldname, fieldmeta):
+def to_json_data(request, model, instance, fieldname, fieldmeta):
     """Convert a model field to JSON on the server.
     """
     value = getattr(instance, fieldname)
@@ -26,7 +26,7 @@ def to_json_data(model, instance, fieldname, fieldmeta):
                 data = root + rel_to.path + 'data/%s/' % value.pk)
     elif DATA_MAPPING.has_key(fieldmeta['type']):
         return DATA_MAPPING[fieldmeta['type']](
-            model, instance, fieldmeta, value)
+            request, model, instance, fieldmeta, value)
     else:
         if value is None:
             return None
